@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::MakeMaker::Fallback; # git description: v0.016-17-gf4cff03
+package Dist::Zilla::Plugin::MakeMaker::Fallback; # git description: v0.017-4-gd38b4d7
 # ABSTRACT: Generate a Makefile.PL containing a warning for legacy users
 # KEYWORDS: plugin installer MakeMaker Makefile.PL toolchain legacy ancient backcompat
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::MakeMaker::Awesome' => { -version => '0.15' };
@@ -78,7 +78,9 @@ CODE
     delete $configure_requires->{perl};
 
     # prereq specifications don't always provide exact versions - we just weed
-    # those out for now, as this shouldn't occur that frequently.
+    # those out for now, as this shouldn't occur that frequently.  There is no
+    # point in using CPAN::Meta, as that wasn't in core in the range of perl
+    # versions that is likely to not have satisfied these prereqs.
     delete @{$configure_requires}{ grep { not version::is_strict($configure_requires->{$_}) } keys %$configure_requires };
     join('', map {
             "    '$_' => '$configure_requires->{$_}',\n"
@@ -255,7 +257,7 @@ Dist::Zilla::Plugin::MakeMaker::Fallback - Generate a Makefile.PL containing a w
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
